@@ -14,7 +14,7 @@ Trading project:
 #   add inner class with non-trading utils
 #   add tradingview realtime signals
 #   numpy
-#   all trading on client
+#   scalper and dca bot
 
 import random
 import time
@@ -52,7 +52,7 @@ class Trader(object):
     ticker: str
     interval: str
     __exit_order__: bool = False
-    _old_predict: str = 'Exit'
+    _prev_predict: str = 'Exit'
     _regression_inputs: int
     _stop_loss: float
     _take_profit: float
@@ -78,16 +78,21 @@ class Trader(object):
     _sec_interval: int
     supports: Dict[int, float]
     resistances: Dict[int, float]
+    __last_credit_leverage: float
+    __prev_credit_lev: float = 1
+    trading_on_client: bool
 
     def __init__(self,
                  ticker: str = 'BTC/USDT',
                  df: pd.DataFrame = pd.DataFrame(),
                  interval: str = '1d',
+                 trading_on_client: bool = False,
                  *args,
                  **kwargs):
         self.df = df.reset_index(drop=True)
         self.ticker = ticker
         self.interval = interval
+        self.trading_on_client = trading_on_client
         if interval == '1m':
             self._profit_calculate_coef = 1 / (60 * 24 * 365)
             self._sec_interval = 60
@@ -559,6 +564,7 @@ class Trader(object):
                     flag = utils.EXIT
             self.returns.append(flag)
         self.set_open_stop_and_take()
+        self.set_credit_leverages()
         return self.returns
 
     def get_heikin_ashi(self, df: pd.DataFrame = pd.DataFrame()) -> pd.DataFrame:
@@ -925,7 +931,7 @@ winrate: {self.winrate}%"""
                                                                 'bprice': [],
                                                                 'sprice': [],
                                                                 'eprice': []}
-            for e, i in enumerate(seted_, 0):
+            for e, i in enumerate(seted_):
                 if i == utils.SELL:
                     preds['sellind'].append(e)
                     preds['sprice'].append(loc[e])
@@ -1193,10 +1199,11 @@ winrate: {self.winrate}%"""
         if len(strategies) >= 3:
             for ret in strategies[2:]:
                 self.strategy_collider(self.returns, ret, mode=mode)
+        self.set_open_stop_and_take()
+        self.set_credit_leverages()
         return self.returns
 
     def get_trading_predict(self,
-                            trading_on_client: bool = False,
                             bet_for_trading_on_client: float = np.inf,
                             coin_lotsize_division=True
                             ) -> Dict[str, typing.Union[str, float]]:
@@ -1204,7 +1211,6 @@ winrate: {self.winrate}%"""
         predict and trading.
 
         :param coin_lotsize_division: If for your api you specify the size of the bet in a coin, which is not in which you have a deposit, specify this parameter in the value: True. Otherwise: False, in Binance's case this is definitely the first case (True). If errors occur, try specifying the first ticker symbol instead of the second.
-        :param trading_on_client: trading on real client
         :param bet_for_trading_on_client: standard: all deposit
         :return: dict with prediction
         """
@@ -1218,7 +1224,7 @@ winrate: {self.winrate}%"""
         # get prediction
         predict = self.returns[-1]
         predict = utils.convert_signal_str(predict)
-        if self.__exit_order__ and self._old_predict == predict:
+        if self.__exit_order__ and self._prev_predict == predict:
             predict = 'Exit'
         if predict != 'Exit':
             self.__exit_order__ = False
@@ -1226,10 +1232,11 @@ winrate: {self.winrate}%"""
         # trading
         self.__last_stop_loss = self._stop_losses[-1]
         self.__last_take_profit = self._take_profits[-1]
-        if self._old_predict != predict:
+        self.__last_credit_leverage = self._credit_leverages[-1]
+        if self._prev_predict != predict or self.__prev_credit_lev != self.__last_credit_leverage:
             utils.logger.info(f'open lot {predict}')
             self._open_price = close[-1]
-            if trading_on_client:
+            if self.trading_on_client:
 
                 if predict == 'Exit':
                     self.client.exit_last_order()
@@ -1249,39 +1256,39 @@ winrate: {self.winrate}%"""
 
                     self.client.order_create(predict,
                                              self.ticker,
-                                             bet)
+                                             bet*credit_leverage)
                     self.__exit_order__ = False
         return {
             'predict': predict,
             'open lot price': self._open_price,
             'stop loss': self.__last_stop_loss,
             'take profit': self.__last_take_profit,
-            'currency close': close[-1]
+            'currency close': close[-1],
+            'credit leverage': self.__last_credit_leverage
         }
 
     def realtime_trading(self,
                          strategy,
                          ticker: str = 'BTC/USDT',
                          print_out: bool = True,
-                         trading_on_client: bool = False,
                          bet_for_trading_on_client: float = np.inf,
                          coin_lotsize_division: bool = True,
                          ignore_exceptions: bool = True,
                          print_exc: bool = True,
                          wait_sl_tp_checking: float = 5,
                          limit: int = 1000,
+                         strategy_in_sleep: bool = False,
                          *strategy_args,
                          **strategy_kwargs):
         """
         :param limit: client.get_data_historical's limit argument
-        :param wait_sl_tp_checking: sleeping time after stop-loaa and take-profit checking (seconds)
+        :param wait_sl_tp_checking: sleeping time after stop-loss and take-profit checking (seconds)
         :param print_exc: print  exceptions in while loop
         :param ignore_exceptions: ignore binance exceptions in while loop
         :param coin_lotsize_division: If for your api you specify the size of the bet in a coin, which is not in which you have a deposit, specify this parameter in the value: True. Otherwise: False, in Binance's case this is definitely the first case (True). If errors occur, try specifying the first ticker symbol instead of the second.
         :param ticker: ticker for trading.
         :param strategy: trading strategy.
         :param print_out: printing.
-        :param trading_on_client: trading on client
         :param bet_for_trading_on_client: trading bet, standard: all deposit
         :param strategy_kwargs: named arguments to -strategy.
         :param strategy_args: arguments to -strategy.
@@ -1296,7 +1303,6 @@ winrate: {self.winrate}%"""
                 strategy(*strategy_args, **strategy_kwargs)
 
                 prediction = self.get_trading_predict(
-                    trading_on_client=trading_on_client,
                     bet_for_trading_on_client=bet_for_trading_on_client,
                     coin_lotsize_division=coin_lotsize_division)
 
@@ -1320,11 +1326,13 @@ winrate: {self.winrate}%"""
                             if print_out:
                                 print(f"trading prediction exit in sleeping at {index}: {prediction}")
                             self.realtime_returns[index] = prediction
-                            if trading_on_client:
+                            if self.trading_on_client:
                                 self.client.exit_last_order()
+                        elif strategy_in_sleep:
+                            strategy(*strategy_args, **strategy_kwargs)
                     time.sleep(wait_sl_tp_checking)
                     if not (time.time() < (__now__ + self._sec_interval)):
-                        self._old_predict = utils.convert_signal_str(self.returns[-1])
+                        self._prev_predict = utils.convert_signal_str(self.returns[-1])
                         __now__ += self._sec_interval
                         break
             except Exception as exc:
@@ -1416,6 +1424,7 @@ winrate: {self.winrate}%"""
         Sets the leverage for bets.
         :param credit_lev: leverage in points
         """
+        self.__prev_credit_lev = credit_lev
         self._credit_leverages = [credit_lev for i in range(len(self.df['Close']))]
         utils.logger.debug(f'trader credit leverage: {credit_lev}')
 
@@ -1617,7 +1626,6 @@ winrate: {self.winrate}%"""
         )
 
         patterns = map(utils.anti_set_, patterns)
-        self.set_open_stop_and_take()
         return self.multi_strategy_collider(*patterns, mode='super')
 
     def get_support_resistanse(self) -> Dict[str, Dict[int, float]]:
